Index: src/mirror-debugger.js |
diff --git a/src/mirror-debugger.js b/src/mirror-debugger.js |
index 124347b7bd5b72cd7a977750b91a2d608aa951e2..75dd260a765ba1cb29eeb00c0b71f87c12eb4da6 100644 |
--- a/src/mirror-debugger.js |
+++ b/src/mirror-debugger.js |
@@ -640,9 +640,9 @@ ObjectMirror.prototype.propertyNames = function(kind, limit) { |
// Find all the named properties. |
if (kind & PropertyKind.Named) { |
// Get all the local property names except for private symbols. |
propertyNames = |
- %GetLocalPropertyNames(this.value_, PROPERTY_ATTRIBUTES_PRIVATE_SYMBOL); |
+ %GetOwnPropertyNames(this.value_, PROPERTY_ATTRIBUTES_PRIVATE_SYMBOL); |
total += propertyNames.length; |
// Get names for named interceptor properties if any. |
@@ -658,8 +658,8 @@ ObjectMirror.prototype.propertyNames = function(kind, limit) { |
// Find all the indexed properties. |
if (kind & PropertyKind.Indexed) { |
- // Get the local element names. |
- elementNames = %GetLocalElementNames(this.value_); |
+ // Get own element names. |
+ elementNames = %GetOwnElementNames(this.value_); |
total += elementNames.length; |
// Get names for indexed interceptor properties. |
@@ -640,9 +640,9 @@ ObjectMirror.prototype.propertyNames = function(kind, limit) { |
// Find all the named properties. |
if (kind & PropertyKind.Named) { |
- // Get all the local property names except for private symbols. |
+ // Get all own property names except for private symbols. |
propertyNames = |